@@ -342,7 +342,7 @@ create_menubar (GtkWidget *win)
   // only for check menu item.
   {
     gchar *remember_fe = NULL;
-    remember_fe = read_config ("remember_frontend");
+    remember_fe = read_config ("remember-frontend");
     if (!strcmp (remember_fe, "yes") && fe_toggle)
       GTK_CHECK_MENU_ITEM(fe_toggle)->active = TRUE;
     g_free (remember_fe);
@@ -511,7 +511,6 @@ void gtk_list_store_set_strings (GtkListStore *store, GList *list)
 void list_item_selected(GtkTreeSelection *selection, gpointer data)
 {
   GtkTreeIter iter;
-  GtkTreeView *tree_view;
   GtkTreeModel *model;
   GtkTreePath *path;
 
@@ -522,8 +521,6 @@ void list_item_selected(GtkTreeSelection *selection, gpointer data)
   GList *cflist = (GList *) data;
   GList *pkgsec_list_copy = g_list_copy(pkgsec_list);
 
-  tree_view = gtk_tree_selection_get_tree_view (selection);
-
   if (gtk_tree_selection_get_selected (selection, &model, &iter))
     {
       gtk_tree_model_get (model, &iter, 0, &item_data_string, -1);
